==> h20kcod.db_2.3.0.tar.gz: h20kcod.db/man/h20kcod_dbconn.Rd <==
\name{h20kcod_dbconn}

\alias{h20kcod_dbconn}
\alias{h20kcod_dbfile}
\alias{h20kcod_dbschema}
\alias{h20kcod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  h20kcod_dbconn()
  h20kcod_dbfile()
  h20kcod_dbschema(file="", show.indices=FALSE)
  h20kcod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{h20kcod_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{h20kcod_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{h20kcod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{h20kcod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{h20kcod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{h20kcod_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{h20kcod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{h20kcod_dbschema}: none (invisible \code{NULL}).

  \code{h20kcod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(h20kcod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by h20kcod_dbconn() was created with:
  dbConnect(SQLite(), dbname=h20kcod_dbfile(), cache_size=64000, synchronous=0)

  h20kcod_dbschema()

  h20kcod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> h20kcod.db_2.12.0.tar.gz: h20kcod.db/man/h20kcod_dbconn.Rd <==

\name{h20kcod_dbconn}

\alias{h20kcod_dbconn}
\alias{h20kcod_dbfile}
\alias{h20kcod_dbschema}
\alias{h20kcod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  h20kcod_dbconn()
  h20kcod_dbfile()
  h20kcod_dbschema(file="", show.indices=FALSE)
  h20kcod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{h20kcod_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{h20kcod_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{h20kcod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{h20kcod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{h20kcod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{h20kcod_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{h20kcod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{h20kcod_dbschema}: none (invisible \code{NULL}).

  \code{h20kcod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(h20kcod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by h20kcod_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=h20kcod_dbfile(), cache_size=64000,
  synchronous=0)

  h20kcod_dbschema()

  h20kcod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
